@@ -19,6 +19,28 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#include "config.h"
+
+#include "seahorse-context.h"
+#include "seahorse-daemon.h"
+#include "seahorse-gconf.h"
+#include "seahorse-gtkstock.h"
+#include "seahorse-secure-memory.h"
+#include "seahorse-unix-signal.h"
+
+#include "common/seahorse-cleanup.h"
+#include "common/seahorse-registry.h"
+
+#ifdef WITH_PGP
+#include "pgp/seahorse-pgp-module.h"
+#endif
+
+#ifdef WITH_SSH
+#include "ssh/seahorse-ssh-module.h"
+#endif
+
+#include <glib/gi18n.h>
+
 #include <sys/types.h>
 #include <sys/signal.h>
 
@@ -30,16 +52,6 @@
 #include <syslog.h>
 #include <fcntl.h>
 
-#include <gnome.h>
-
-#include "config.h"
-#include "seahorse-daemon.h"
-#include "seahorse-secure-memory.h"
-#include "seahorse-gconf.h"
-#include "seahorse-gtkstock.h"
-#include "seahorse-context.h"
-#include "seahorse-unix-signal.h"
-
 static gboolean daemon_no_daemonize = FALSE;
 static gboolean daemon_running = FALSE;
 static gboolean daemon_quit = FALSE;
@@ -86,7 +98,9 @@ daemonize ()
             open ("/dev/null", O_WRONLY, 0666);
             open ("/dev/null", O_WRONLY, 0666);
 
-            chdir ("/tmp");
+            if (chdir ("/tmp") < 0)
+                warn ("couldn't change to /tmp directory");
+            
             return; /* Child process returns */
         };
     }
@@ -166,41 +180,26 @@ prepare_logging ()
     g_log_set_handler ("Gnome", flags, log_handler, NULL);
 }
 
-static void
-client_die ()
-{
-    gtk_main_quit ();
-}
-
 int main(int argc, char* argv[])
 {
     SeahorseOperation *op;
-    GnomeClient *client = NULL;
     GOptionContext *octx = NULL;
+    GError *error = NULL;
 
-    seahorse_secure_memory_init (65536);
+    g_thread_init (NULL);
     
-    /* We need to drop privileges completely for security */
-#if defined(HAVE_SETRESUID) && defined(HAVE_SETRESGID)
-
-    /* Not in header files for all OSs, even where present */
-    int setresuid(uid_t ruid, uid_t euid, uid_t suid);
-    int setresgid(gid_t rgid, gid_t egid, gid_t sgid);
-  
-    if (setresuid (getuid (), getuid (), getuid ()) == -1 ||
-        setresgid (getgid (), getgid (), getgid ()) == -1)
-#else
-    if (setuid (getuid ()) == -1 || setgid (getgid ()) == -1)
-#endif
-        err (1, _("couldn't drop privileges properly"));
+    seahorse_secure_memory_init ();
     
     octx = g_option_context_new ("");
     g_option_context_add_main_entries (octx, options, GETTEXT_PACKAGE);
 
-    gnome_program_init ("seahorse-daemon", VERSION, LIBGNOMEUI_MODULE, argc, argv,
-                    GNOME_PARAM_GOPTION_CONTEXT, octx,
-                    GNOME_PARAM_HUMAN_READABLE_NAME, _("Encryption Daemon (Seahorse)"),
-                    GNOME_PARAM_APP_DATADIR, DATA_DIR, NULL);
+    if (!gtk_init_with_args (&argc, &argv, _("Encryption Daemon (Seahorse)"), 
+                             (GOptionEntry *)options, GETTEXT_PACKAGE, &error)) {
+	    g_printerr ("seahorse-daemon: %s\n", error->message);
+	    g_error_free (error);
+	    exit (1);
+    }
+	    
 
     /* 
      * All functions after this point have to print messages 
@@ -216,9 +215,6 @@ int main(int argc, char* argv[])
     if (!daemon_no_daemonize)
         seahorse_gconf_disconnect ();    
         
-    client = gnome_master_client();
-    g_signal_connect(client, "die", G_CALLBACK(client_die), NULL);
-    
     /* We log to the syslog */
     prepare_logging ();
 
@@ -227,8 +223,17 @@ int main(int argc, char* argv[])
     seahorse_gtkstock_add_icons (daemon_icons);
     
     /* Make the default SeahorseContext */
-    seahorse_context_new (SEAHORSE_CONTEXT_APP | SEAHORSE_CONTEXT_DAEMON, 0);
-    op = seahorse_context_load_local_keys (SCTX_APP ());
+    seahorse_context_new (SEAHORSE_CONTEXT_APP | SEAHORSE_CONTEXT_DAEMON);
+
+    /* Load the various components */
+#ifdef WITH_PGP
+    seahorse_pgp_module_init ();
+#endif
+#ifdef WITH_SSH
+    seahorse_ssh_module_init ();
+#endif
+    
+    op = seahorse_context_refresh_local (NULL);
     g_object_unref (op);
     
     /* Initialize the various daemon components */
@@ -253,6 +258,7 @@ int main(int argc, char* argv[])
     seahorse_dbus_server_cleanup ();
 
     seahorse_context_destroy (SCTX_APP ());
+    seahorse_cleanup_perform ();
 
     return 0;
 }
