@@ -79,7 +79,7 @@ seahorse_util_show_error (GtkWidget *parent, const gchar *heading, const gchar *
 	
 	error = gtk_message_dialog_new_with_markup (GTK_WINDOW (parent), 
 	                                            GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-	                                            GTK_BUTTONS_CLOSE, text);
+	                                            GTK_BUTTONS_CLOSE, "%s", text);
 	g_free (text);
 	
 	gtk_dialog_run (GTK_DIALOG (error));
@@ -108,12 +108,24 @@ seahorse_util_handle_error (GError* err, const char* desc, ...)
 }    
 
 gboolean
-seahorse_util_prompt_delete (const gchar *text)
+seahorse_util_prompt_delete (const gchar *text, GtkWidget *parent)
 {
 	GtkWidget *warning, *button;
 	gint response;
 	
-	warning = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+	if (parent) {
+		if (!GTK_IS_WIDGET (parent)) {
+			g_warn_if_reached ();
+			parent = NULL;
+		} else {
+			if (!GTK_IS_WINDOW (parent)) 
+				parent = gtk_widget_get_toplevel (parent);
+			if (!GTK_IS_WINDOW (parent) && GTK_WIDGET_TOPLEVEL (parent))
+				parent = NULL;
+		}
+	}
+	
+	warning = gtk_message_dialog_new (GTK_WINDOW (parent), GTK_DIALOG_MODAL,
 	                                  GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
 	                                  "%s", text);
     
@@ -219,7 +231,7 @@ seahorse_util_set_text_view_string (GtkTextView *view, GString *string)
 }
 
 /**
- * seahorse_util_read_to_text:
+ * seahorse_util_read_to_memory:
  * @data: Data to write
  * @len: Length of the data
  *
@@ -227,8 +239,8 @@ seahorse_util_set_text_view_string (GtkTextView *view, GString *string)
  *
  * Returns: The string read from data
  **/
-gchar*
-seahorse_util_read_to_text (GInputStream *input, guint *len)
+guchar*
+seahorse_util_read_to_memory (GInputStream *input, guint *len)
 {
 	gint size = 128;
 	gchar *buffer, *text;
@@ -254,7 +266,7 @@ seahorse_util_read_to_text (GInputStream *input, guint *len)
 	g_string_free (string, FALSE);
 	g_free (buffer);
 	
-	return text;
+	return (guchar*)text;
 }
 
 /** 
@@ -313,6 +325,13 @@ seahorse_util_read_data_block (GString *buf, GInputStream *input,
     return copied;
 }
 
+GMemoryInputStream*
+seahorse_util_memory_input_string (const gchar *string, gsize length)
+{
+	g_return_val_if_fail (string, NULL);
+	return G_MEMORY_INPUT_STREAM (g_memory_input_stream_new_from_data (g_strndup (string, length), length, g_free));
+}
+
 gsize
 seahorse_util_memory_output_length (GMemoryOutputStream *output)
 {
@@ -667,7 +686,7 @@ seahorse_util_uris_package (const gchar* package, const char** uris)
     	g_object_unref (fpackage);
 
     if (out) {
-        g_print (out);
+        g_print ("%s", out);
         g_free (out);
     }
     
@@ -1229,6 +1248,23 @@ seahorse_util_string_trim_whitespace (gchar *text)
     g_memmove (text, b, (e + 1) - b);
 }
 
+gchar*
+seahorse_util_hex_encode (gconstpointer value, gsize length)
+{
+	GString *result;
+	gsize i;
+	
+	result = g_string_sized_new ((length * 2) + 1);
+
+	for (i = 0; i < length; i++) {
+		char hex[3];
+		snprintf (hex, sizeof (hex), "%02x", (int)(((guchar*)value)[i]));
+		g_string_append (result, hex);
+	}
+
+	return g_string_free (result, FALSE);
+}
+
 /* Callback to determine where a popup menu should be placed */
 void
 seahorse_util_determine_popup_menu_position (GtkMenu *menu, int *x, int *y,
